@@ -42,24 +42,6 @@ OC.L10N.register(
     "Deck" : "Kartaro",
     "Changes in the <strong>Deck app</strong>" : "Ŝanĝoj en la <strong>aplikaĵo Kartaro</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komento</strong> kreiĝis sur karton",
-    "Personal" : "Persona",
-    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La karto „%s“ sur „%s“ estis atribuita al vi de %s.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "La karto „%s“ sur „%s“ atingis sian limdaton.",
-    "%s has mentioned you in a comment on \"%s\"." : "%s menciis vin en komento ĉe „%s“.",
-    "The board \"%s\" has been shared with you by %s." : "La tabulo „%s“ estis kunhavigita kun vi de %s.",
-    "%s on %s" : "%s el %s",
-    "No data was provided to create an attachment." : "Neniu datumo troviĝis por krei aldonaĵon.",
-    "Finished" : "Finita",
-    "To review" : "Reviziota",
-    "Action needed" : "Ago bezonata",
-    "Later" : "Poste",
-    "copy" : "kopio",
-    "To do" : "Farota",
-    "Doing" : "Farata",
-    "Done" : "Farita",
-    "Example Task 3" : "Ekzempla tasko 3",
-    "Example Task 2" : "Ekzempla tasko 2",
-    "Example Task 1" : "Ekzempla tasko 1",
     "The file was uploaded" : "La dosiero alŝutiĝis",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon „MAX_FILE_SIZE“ specifita en la HTML-formularo",
@@ -69,6 +51,19 @@ OC.L10N.register(
     "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
     "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
     "No file uploaded or file size exceeds maximum of %s" : "Neniu dosiero alŝutita, aŭ dosiergrando transpasas la maksimumon %s",
+    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La karto „%s“ sur „%s“ estis atribuita al vi de %s.",
+    "%s has mentioned you in a comment on \"%s\"." : "%s menciis vin en komento ĉe „%s“.",
+    "The board \"%s\" has been shared with you by %s." : "La tabulo „%s“ estis kunhavigita kun vi de %s.",
+    "%s on %s" : "%s el %s",
+    "No data was provided to create an attachment." : "Neniu datumo troviĝis por krei aldonaĵon.",
+    "Finished" : "Finita",
+    "To review" : "Reviziota",
+    "Action needed" : "Ago bezonata",
+    "Later" : "Poste",
+    "copy" : "kopio",
+    "Done" : "Farita",
+    "Attachments" : "Dosieraj aldonaĵoj",
+    "File" : "Dosiero",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
     "Select the board to link to a project" : "Elekti la tabulon ligotan al projekto",
     "Select board" : "Elekti tabulon",
@@ -97,20 +92,19 @@ OC.L10N.register(
     "Edit" : "Redakti",
     "Members" : "Membroj",
     "Download" : "Elŝuti",
-    "Attachments" : "Dosieraj aldonaĵoj",
-    "Comments" : "Komentoj",
     "Modified" : "Modifita",
     "Created" : "Kreita",
+    "Comments" : "Komentoj",
     "Save" : "Konservi",
+    "Created:" : "Kreita:",
     "Reply" : "Respondi",
     "Update" : "Ĝisdatigi",
-    "Created:" : "Kreita:",
     "Description" : "Priskribo",
     "Formatting help" : "Helpo pri tekstaranĝo",
+    "Select Date" : "Elekti daton",
     "Remove due date" : "Viŝi limdaton",
     "Unarchive card" : "Malarĥivigi karton",
     "Archive card" : "Arĥivigi karton",
-    "Select Date" : "Elekti daton",
     "(group)" : "(grupo)",
     "Delete card" : "Forigi karton",
     "seconds ago" : "antaŭ kelkaj sekundoj",
@@ -118,18 +112,28 @@ OC.L10N.register(
     "Search" : "Serĉi",
     "Archived boards" : "Arĥivigitaj tabuloj",
     "Shared with you" : "Kunhavata kun vi",
+    "An error occurred" : "Eraro okazis",
     "Edit board" : "Modifi tabulon",
     "Unarchive board" : "Elarĥivigi tabulon",
     "Archive board" : "Enarĥivigi tabulon",
     "No notifications" : "Neniu sciigo",
     "Delete board" : "Forigi tabulon",
-    "An error occurred" : "Eraro okazis",
-    "Today" : "Hodiaŭ",
-    "Tomorrow" : "Morgaŭ",
+    "Advanced options" : "Detalaj agordoj",
+    "Export" : "Eksporti",
     "Close" : "Malfermi",
     "Link to a board" : "Ligilo al tabulo",
     "Maximum file size of {size} exceeded" : "Maksimuma dosiergrando {size} transpasita",
+    "Due date" : "Limdato",
     "Error creating the share" : "Eraro dum kreo de la kunhavigo",
-    "Share" : "Kunhavigi"
+    "Share" : "Kunhavigi",
+    "Personal" : "Persona",
+    "The card \"%s\" on \"%s\" has reached its due date." : "La karto „%s“ sur „%s“ atingis sian limdaton.",
+    "To do" : "Farota",
+    "Doing" : "Farata",
+    "Example Task 3" : "Ekzempla tasko 3",
+    "Example Task 2" : "Ekzempla tasko 2",
+    "Example Task 1" : "Ekzempla tasko 1",
+    "Today" : "Hodiaŭ",
+    "Tomorrow" : "Morgaŭ"
 },
 "nplurals=2; plural=(n != 1);");
