@@ -85,7 +85,6 @@ OC.L10N.register(
     "Cards due tomorrow" : "Tarjetas para mañana",
     "Upcoming cards" : "Tarjetas próximas",
     "Load more" : "Cargar más",
-    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "Deck board" : "Tablero de Deck",
     "%s on %s" : "%s en %s",
@@ -187,12 +186,13 @@ OC.L10N.register(
     "Advanced options" : "Opciones avanzadas",
     "Clone" : "Clonar",
     "Export" : "Exportar",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
     "Close" : "Cerrar",
     "Due date" : "Fecha de vencimiento",
     "Error creating the share" : "Error creando el recurso compartido",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
