@@ -1,14 +1,12 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "පුද්ගලික",
-    "Later" : "පසුව",
-    "copy" : "පිටපත්",
-    "Example Task 3" : "උදාහරණ කාර්යය 3",
-    "Example Task 2" : "උදාහරණ කාර්යය 2",
-    "Example Task 1" : "උදාහරණ කාර්යය 1",
     "No file was uploaded" : "කිසිදු ගොනුවක් උඩුගත කර නොමැත",
     "Missing a temporary folder" : "තාවකාලික බහාලුමක් අස්ථානගත වී ඇත",
+    "Later" : "පසුව",
+    "copy" : "පිටපත්",
+    "Attachments" : "ඇමිණුම්",
+    "File" : "ගොනුව",
     "Cancel" : "අවලංගු කරන්න",
     "File already exists" : "ගොනුව දැනටමත් පවතී",
     "Add list" : "ලැයිස්තුව එකතු කරන්න",
@@ -21,7 +19,6 @@ OC.L10N.register(
     "Owner" : "හිමිකරු",
     "Edit" : "සංස්කරණය",
     "Download" : "බාගන්න",
-    "Attachments" : "ඇමිණුම්",
     "Comments" : "අදහස්",
     "Save" : "සුරකින්න",
     "Reply" : "පිළිතුර",
@@ -30,9 +27,13 @@ OC.L10N.register(
     "Select Date" : "දිනය තෝරන්න",
     "seconds ago" : "තත්පර කිහිපයකට පෙර",
     "Search" : "සොයන්න",
-    "Today" : "අද",
-    "Tomorrow" : "හෙට",
     "Close" : "වසන්න",
-    "Share" : "බෙදාගන්න"
+    "Share" : "බෙදාගන්න",
+    "Personal" : "පුද්ගලික",
+    "Example Task 3" : "උදාහරණ කාර්යය 3",
+    "Example Task 2" : "උදාහරණ කාර්යය 2",
+    "Example Task 1" : "උදාහරණ කාර්යය 1",
+    "Today" : "අද",
+    "Tomorrow" : "හෙට"
 },
 "nplurals=2; plural=(n != 1);");
