@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -152,6 +153,30 @@ class CardApiController extends ApiController {
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 *
+	 * Archive card
+	 */
+	public function archive($cardId) {
+		$card = $this->cardService->archive($cardId);
+		return new DataResponse($card, HTTP::STATUS_OK);
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 *
+	 * Unarchive card
+	 */
+	public function unarchive($cardId) {
+		$card = $this->cardService->unarchive($cardId);
+		return new DataResponse($card, HTTP::STATUS_OK);
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @CORS
@@ -160,7 +185,7 @@ class CardApiController extends ApiController {
 	 * Reorder cards
 	 */
 	public function reorder($stackId, $order) {
-		$card = $this->cardService->reorder($this->request->getParam('cardId'), $stackId, $order);
+		$card = $this->cardService->reorder((int)$this->request->getParam('cardId'), (int)$stackId, (int)$order);
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
 }
